csep.core.forecasts.GriddedForecast.get\_magnitude\_index
=========================================================

.. currentmodule:: csep.core.forecasts

.. automethod:: GriddedForecast.get_magnitude_index